"use client"

import LoadingItem from "@/components/loading-item"
import { TryAgain } from "@/components/try-again"
import { Card } from "@/components/ui/card"
import Link from "next/link"
import { useHashtags } from "../hooks/use-hashtags"
import { Trend } from "./trend"

export const Trends = ({ title = "Trends" }: { title?: string }) => {
    const { data: hashtags, isLoading, isError, isSuccess } = useHashtags()

    return (
        <div className="space-y-5 flex flex-col">
            {title && <h1 className="font-bold p-1">{title}</h1>}
            {isLoading ? (
                <LoadingItem />
            ) : isError ? (
                <TryAgain />
            ) : hashtags?.length <= 0 ? (
                <Card className="p-1">
                    <h1 className="text-center">No trends yet</h1>
                </Card>
            ) : isSuccess &&
            hashtags?.slice(title ? 0 : undefined, title ? 3 : undefined).map((hashtag, index) => {
                return (
                    <Trend
                        key={hashtag.id}
                        ranking={index + 1}
                        title={hashtag.text}
                        gweets={hashtag.score}
                    />
                )
            })}
            {title && <Link href={"/trends"} className="self-end hover:bg-accent p-1 rounded-lg">See more</Link>}
        </div>
    )
}